<!DOCTYPE html>
<html lang="en" data-bs-theme="auto">

<head>
  <!-- TEMPLATE_HEADER - Used by Every UI Page -->
<meta charset="UTF-8" />
<meta http-equiv="X-UA-Compatible" content="IE=edge" />
<meta name="viewport" content="width=device-width, initial-scale=1.0" />
<title>Sunshine</title>
<link rel="icon" type="image/x-icon" href="./images/sunshine.ico">
<link href="./assets/css/sunshine.css" rel="stylesheet" />

  <script type="module" crossorigin src="./assets/logout-DiLZqZLO.js"></script>
  <link rel="modulepreload" crossorigin href="./assets/createLucideIcon-mjjtyxlm.js">
  <link rel="stylesheet" crossorigin href="./assets/createLucideIcon-BL5QWnkG.css">
</head>

<body id="app" v-cloak>
  <div class="container py-5">
    <div class="row justify-content-center">
      <div class="col-md-8 col-lg-6">
        <div class="card">
          <div class="card-body text-center">
            <img src="./images/logo-sunshine-45.png" height="45" alt="Sunshine" class="mb-3">
            <h1 class="h3 mb-3">{{ $t('logout.logged_out') }}</h1>
            <p class="text-muted mb-4">{{ $t('logout.logged_out_desc') }}</p>
            <a class="btn btn-primary" href="./">
              <log-in :size="18" class="icon"></log-in>
              {{ $t('logout.login') }}
            </a>
          </div>
        </div>
      </div>
    </div>
  </div>
</body>

</html>
