import{c as l,C as j,d as _,e,h as o,u as c,t as s,j as n,o as w,D as r}from"./createLucideIcon-mjjtyxlm.js";import{_ as H,I as E,N}from"./Notification-E6BjStlk.js";/**
 * @license lucide-vue-next v1.0.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const U=l("circle-user-round",[["path",{d:"M18 20a6 6 0 0 0-12 0",key:"1qehca"}],["circle",{cx:"12",cy:"10",r:"4",key:"1h16sb"}],["circle",{cx:"12",cy:"12",r:"10",key:"1mglay"}]]);/**
 * @license lucide-vue-next v1.0.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const I=l("cloud-moon",[["path",{d:"M13 16a3 3 0 0 1 0 6H7a5 5 0 1 1 4.9-6z",key:"ie2ih4"}],["path",{d:"M18.376 14.512a6 6 0 0 0 3.461-4.127c.148-.625-.659-.97-1.248-.714a4 4 0 0 1-5.259-5.26c.255-.589-.09-1.395-.716-1.248a6 6 0 0 0-4.594 5.36",key:"zwnc1e"}]]);/**
 * @license lucide-vue-next v1.0.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const V=l("cloud-rain",[["path",{d:"M4 14.899A7 7 0 1 1 15.71 8h1.79a4.5 4.5 0 0 1 2.5 8.242",key:"1pljnt"}],["path",{d:"M16 14v6",key:"1j4efv"}],["path",{d:"M8 14v6",key:"17c4r9"}],["path",{d:"M12 16v6",key:"c8a4gj"}]]);/**
 * @license lucide-vue-next v1.0.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const R=l("contrast",[["circle",{cx:"12",cy:"12",r:"10",key:"1mglay"}],["path",{d:"M12 18a6 6 0 0 0 0-12v12z",key:"j4l70d"}]]);/**
 * @license lucide-vue-next v1.0.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const B=l("flame",[["path",{d:"M12 3q1 4 4 6.5t3 5.5a1 1 0 0 1-14 0 5 5 0 0 1 1-3 1 1 0 0 0 5 0c0-2-1.5-3-1.5-5q0-2 2.5-4",key:"1slcih"}]]);/**
 * @license lucide-vue-next v1.0.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const P=l("flower-2",[["path",{d:"M12 5a3 3 0 1 1 3 3m-3-3a3 3 0 1 0-3 3m3-3v1M9 8a3 3 0 1 0 3 3M9 8h1m5 0a3 3 0 1 1-3 3m3-3h-1m-2 3v-1",key:"3pnvol"}],["circle",{cx:"12",cy:"8",r:"2",key:"1822b1"}],["path",{d:"M12 10v12",key:"6ubwww"}],["path",{d:"M12 22c4.2 0 7-1.667 7-5-4.2 0-7 1.667-7 5Z",key:"9hd38g"}],["path",{d:"M12 22c-4.2 0-7-1.667-7-5 4.2 0 7 1.667 7 5Z",key:"ufn41s"}]]);/**
 * @license lucide-vue-next v1.0.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const D=l("flower",[["circle",{cx:"12",cy:"12",r:"3",key:"1v7zrd"}],["path",{d:"M12 16.5A4.5 4.5 0 1 1 7.5 12 4.5 4.5 0 1 1 12 7.5a4.5 4.5 0 1 1 4.5 4.5 4.5 4.5 0 1 1-4.5 4.5",key:"14wa3c"}],["path",{d:"M12 7.5V9",key:"1oy5b0"}],["path",{d:"M7.5 12H9",key:"eltsq1"}],["path",{d:"M16.5 12H15",key:"vk5kw4"}],["path",{d:"M12 16.5V15",key:"k7eayi"}],["path",{d:"m8 8 1.88 1.88",key:"nxy4qf"}],["path",{d:"M14.12 9.88 16 8",key:"1lst6k"}],["path",{d:"m8 16 1.88-1.88",key:"h2eex1"}],["path",{d:"M14.12 14.12 16 16",key:"uqkrx3"}]]);/**
 * @license lucide-vue-next v1.0.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const O=l("house",[["path",{d:"M15 21v-8a1 1 0 0 0-1-1h-4a1 1 0 0 0-1 1v8",key:"5wwlr5"}],["path",{d:"M3 10a2 2 0 0 1 .709-1.528l7-6a2 2 0 0 1 2.582 0l7 6A2 2 0 0 1 21 10v9a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2z",key:"r6nss1"}]]);/**
 * @license lucide-vue-next v1.0.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const M=l("layers",[["path",{d:"M12.83 2.18a2 2 0 0 0-1.66 0L2.6 6.08a1 1 0 0 0 0 1.83l8.58 3.91a2 2 0 0 0 1.66 0l8.58-3.9a1 1 0 0 0 0-1.83z",key:"zw3jo"}],["path",{d:"M2 12a1 1 0 0 0 .58.91l8.6 3.91a2 2 0 0 0 1.65 0l8.58-3.9A1 1 0 0 0 22 12",key:"1wduqc"}],["path",{d:"M2 17a1 1 0 0 0 .58.91l8.6 3.91a2 2 0 0 0 1.65 0l8.58-3.9A1 1 0 0 0 22 17",key:"kqbvx6"}]]);/**
 * @license lucide-vue-next v1.0.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const F=l("lock",[["rect",{width:"18",height:"11",x:"3",y:"11",rx:"2",ry:"2",key:"1w4ew1"}],["path",{d:"M7 11V7a5 5 0 0 1 10 0v4",key:"fwvmzm"}]]);/**
 * @license lucide-vue-next v1.0.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Z=l("log-out",[["path",{d:"m16 17 5-5-5-5",key:"1bji2h"}],["path",{d:"M21 12H9",key:"dn1m92"}],["path",{d:"M9 21H5a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h4",key:"1uf3rs"}]]);/**
 * @license lucide-vue-next v1.0.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const f=l("monitor-smartphone",[["path",{d:"M18 8V6a2 2 0 0 0-2-2H4a2 2 0 0 0-2 2v7a2 2 0 0 0 2 2h8",key:"10dyio"}],["path",{d:"M10 19v-3.96 3.15",key:"1irgej"}],["path",{d:"M7 19h5",key:"qswx4l"}],["rect",{width:"6",height:"10",x:"16",y:"12",rx:"2",key:"1egngj"}]]);/**
 * @license lucide-vue-next v1.0.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const G=l("moon",[["path",{d:"M20.985 12.486a9 9 0 1 1-9.473-9.472c.405-.022.617.46.402.803a6 6 0 0 0 8.268 8.268c.344-.215.825-.004.803.401",key:"kfwtm"}]]);/**
 * @license lucide-vue-next v1.0.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const W=l("mountain",[["path",{d:"m8 3 4 8 5-5 5 15H2L8 3z",key:"otkl63"}]]);/**
 * @license lucide-vue-next v1.0.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const X=l("settings",[["path",{d:"M9.671 4.136a2.34 2.34 0 0 1 4.659 0 2.34 2.34 0 0 0 3.319 1.915 2.34 2.34 0 0 1 2.33 4.033 2.34 2.34 0 0 0 0 3.831 2.34 2.34 0 0 1-2.33 4.033 2.34 2.34 0 0 0-3.319 1.915 2.34 2.34 0 0 1-4.659 0 2.34 2.34 0 0 0-3.32-1.915 2.34 2.34 0 0 1-2.33-4.033 2.34 2.34 0 0 0 0-3.831A2.34 2.34 0 0 1 6.35 6.051a2.34 2.34 0 0 0 3.319-1.915",key:"1i5ecw"}],["circle",{cx:"12",cy:"12",r:"3",key:"1v7zrd"}]]);/**
 * @license lucide-vue-next v1.0.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const J=l("shield",[["path",{d:"M20 13c0 5-3.5 7.5-7.66 8.95a1 1 0 0 1-.67-.01C7.5 20.5 4 18 4 13V6a1 1 0 0 1 1-1c2 0 4.5-1.2 6.24-2.72a1.17 1.17 0 0 1 1.52 0C14.51 3.81 17 5 19 5a1 1 0 0 1 1 1z",key:"oel41y"}]]);/**
 * @license lucide-vue-next v1.0.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const K=l("sparkles",[["path",{d:"M11.017 2.814a1 1 0 0 1 1.966 0l1.051 5.558a2 2 0 0 0 1.594 1.594l5.558 1.051a1 1 0 0 1 0 1.966l-5.558 1.051a2 2 0 0 0-1.594 1.594l-1.051 5.558a1 1 0 0 1-1.966 0l-1.051-5.558a2 2 0 0 0-1.594-1.594l-5.558-1.051a1 1 0 0 1 0-1.966l5.558-1.051a2 2 0 0 0 1.594-1.594z",key:"1s2grr"}],["path",{d:"M20 2v4",key:"1rf3ol"}],["path",{d:"M22 4h-4",key:"gwowj6"}],["circle",{cx:"4",cy:"20",r:"2",key:"6kqj1y"}]]);/**
 * @license lucide-vue-next v1.0.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Q=l("star",[["path",{d:"M11.525 2.295a.53.53 0 0 1 .95 0l2.31 4.679a2.123 2.123 0 0 0 1.595 1.16l5.166.756a.53.53 0 0 1 .294.904l-3.736 3.638a2.123 2.123 0 0 0-.611 1.878l.882 5.14a.53.53 0 0 1-.771.56l-4.618-2.428a2.122 2.122 0 0 0-1.973 0L6.396 21.01a.53.53 0 0 1-.77-.56l.881-5.139a2.122 2.122 0 0 0-.611-1.879L2.16 9.795a.53.53 0 0 1 .294-.906l5.165-.755a2.122 2.122 0 0 0 1.597-1.16z",key:"r04s7s"}]]);/**
 * @license lucide-vue-next v1.0.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Y=l("sun",[["circle",{cx:"12",cy:"12",r:"4",key:"4exip2"}],["path",{d:"M12 2v2",key:"tus03m"}],["path",{d:"M12 20v2",key:"1lh1kg"}],["path",{d:"m4.93 4.93 1.41 1.41",key:"149t6j"}],["path",{d:"m17.66 17.66 1.41 1.41",key:"ptbguv"}],["path",{d:"M2 12h2",key:"1t8f8n"}],["path",{d:"M20 12h2",key:"1q8mjw"}],["path",{d:"m6.34 17.66-1.41 1.41",key:"1m8zz5"}],["path",{d:"m19.07 4.93-1.41 1.41",key:"1shlcs"}]]);/**
 * @license lucide-vue-next v1.0.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const ee=l("sunrise",[["path",{d:"M12 2v8",key:"1q4o3n"}],["path",{d:"m4.93 10.93 1.41 1.41",key:"2a7f42"}],["path",{d:"M2 18h2",key:"j10viu"}],["path",{d:"M20 18h2",key:"wocana"}],["path",{d:"m19.07 10.93-1.41 1.41",key:"15zs5n"}],["path",{d:"M22 22H2",key:"19qnx5"}],["path",{d:"m8 6 4-4 4 4",key:"ybng9g"}],["path",{d:"M16 18a4 4 0 0 0-8 0",key:"1lzouq"}]]);/**
 * @license lucide-vue-next v1.0.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const te=l("trees",[["path",{d:"M10 10v.2A3 3 0 0 1 8.9 16H5a3 3 0 0 1-1-5.8V10a3 3 0 0 1 6 0Z",key:"1l6gj6"}],["path",{d:"M7 16v6",key:"1a82de"}],["path",{d:"M13 19v3",key:"13sx9i"}],["path",{d:"M12 19h8.3a1 1 0 0 0 .7-1.7L18 14h.3a1 1 0 0 0 .7-1.7L16 9h.2a1 1 0 0 0 .8-1.7L13 3l-1.4 1.5",key:"1sj9kv"}]]);/**
 * @license lucide-vue-next v1.0.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const ae=l("waves",[["path",{d:"M2 6c.6.5 1.2 1 2.5 1C7 7 7 5 9.5 5c2.6 0 2.4 2 5 2 2.5 0 2.5-2 5-2 1.3 0 1.9.5 2.5 1",key:"knzxuh"}],["path",{d:"M2 12c.6.5 1.2 1 2.5 1 2.5 0 2.5-2 5-2 2.6 0 2.4 2 5 2 2.5 0 2.5-2 5-2 1.3 0 1.9.5 2.5 1",key:"2jd2cc"}],["path",{d:"M2 18c.6.5 1.2 1 2.5 1 2.5 0 2.5-2 5-2 2.6 0 2.4 2 5 2 2.5 0 2.5-2 5-2 1.3 0 1.9.5 2.5 1",key:"rd2r6e"}]]),$=()=>localStorage.getItem("theme"),oe=a=>localStorage.setItem("theme",a),b=()=>{const a=$();return a||(window.matchMedia("(prefers-color-scheme: dark)").matches?"dark":"light")},se=new Set(["dark","ember","midnight","moonlight","nord","slate"]),g=a=>{if(a==="auto"){const t=window.matchMedia("(prefers-color-scheme: dark)").matches?"dark":"light";document.documentElement.dataset.bsTheme=t,document.documentElement.dataset.theme=t,console.log(`Theme set to auto (resolved to: ${t})`)}else{const t=se.has(a)?"dark":"light";document.documentElement.dataset.bsTheme=t,document.documentElement.dataset.theme=a,console.log(`Theme set to: ${a} (Bootstrap: ${t})`)}},k=(a,t=!1)=>{const i=document.querySelector("#bd-theme");if(!i)return;const d=document.querySelector("#bd-theme-text"),m=document.querySelector(".theme-icon-active svg"),h=document.querySelector(`[data-bs-theme-value="${a}"]`);if(!h)return;const u=h.querySelector("svg");if(!m||!u)return;document.querySelectorAll("[data-bs-theme-value]").forEach(p=>{p.classList.remove("active"),p.setAttribute("aria-pressed","false")}),h.classList.add("active"),h.setAttribute("aria-pressed","true");const v=u.cloneNode(!0);m.parentNode.replaceChild(v,m);const y=`${d.textContent} (${h.textContent.trim()})`;i.setAttribute("aria-label",y),t&&i.focus()};function ne(){document.querySelectorAll("[data-bs-theme-value]").forEach(a=>{a.addEventListener("click",()=>{const t=a.getAttribute("data-bs-theme-value");oe(t),g(t),k(t,!0)})}),k(b(),!1)}function le(){g(b()),window.matchMedia("(prefers-color-scheme: dark)").addEventListener("change",()=>{const a=$();(a==="auto"||!a)&&g(b())}),window.addEventListener("DOMContentLoaded",()=>{k(b())})}const ie={class:"dropdown bd-mode-toggle"},ce={class:"nav-link dropdown-toggle d-flex align-items-center",id:"bd-theme",type:"button","aria-expanded":"false","data-bs-toggle":"dropdown","aria-label":"{{ $t('navbar.toggle_theme') }} ({{ $t('navbar.theme_auto') }})"},re={class:"theme-icon-active"},de={id:"bd-theme-text"},he={class:"dropdown-menu dropdown-menu-end","aria-labelledby":"bd-theme-text"},me={type:"button",class:"dropdown-item d-flex align-items-center active","data-bs-theme-value":"auto","aria-pressed":"true"},ue={type:"button",class:"dropdown-item d-flex align-items-center","data-bs-theme-value":"dark","aria-pressed":"false"},pe={type:"button",class:"dropdown-item d-flex align-items-center","data-bs-theme-value":"slate","aria-pressed":"false"},be={type:"button",class:"dropdown-item d-flex align-items-center","data-bs-theme-value":"moonlight","aria-pressed":"false"},ve={type:"button",class:"dropdown-item d-flex align-items-center","data-bs-theme-value":"midnight","aria-pressed":"false"},ye={type:"button",class:"dropdown-item d-flex align-items-center","data-bs-theme-value":"ember","aria-pressed":"false"},ge={type:"button",class:"dropdown-item d-flex align-items-center","data-bs-theme-value":"nord","aria-pressed":"false"},ke={type:"button",class:"dropdown-item d-flex align-items-center","data-bs-theme-value":"light","aria-pressed":"false"},fe={type:"button",class:"dropdown-item d-flex align-items-center","data-bs-theme-value":"indigo","aria-pressed":"false"},_e={type:"button",class:"dropdown-item d-flex align-items-center","data-bs-theme-value":"sunshine","aria-pressed":"false"},we={type:"button",class:"dropdown-item d-flex align-items-center","data-bs-theme-value":"ocean","aria-pressed":"false"},Me={type:"button",class:"dropdown-item d-flex align-items-center","data-bs-theme-value":"forest","aria-pressed":"false"},$e={type:"button",class:"dropdown-item d-flex align-items-center","data-bs-theme-value":"rose","aria-pressed":"false"},ze={type:"button",class:"dropdown-item d-flex align-items-center","data-bs-theme-value":"lavender","aria-pressed":"false"},Se={type:"button",class:"dropdown-item d-flex align-items-center","data-bs-theme-value":"monochrome","aria-pressed":"false"},Te={__name:"ThemeToggle",setup(a){return j(()=>{le(),ne()}),(t,i)=>(w(),_("div",ie,[e("a",ce,[e("span",re,[o(c(f),{size:18,class:"icon"})]),e("span",de,s(t.$t("navbar.toggle_theme")),1)]),e("ul",he,[e("li",null,[e("button",me,[o(c(f),{size:18,class:"theme-icon icon"}),n(" "+s(t.$t("navbar.theme_auto")),1)])]),i[0]||(i[0]=e("li",null,[e("hr",{class:"dropdown-divider"})],-1)),e("li",null,[e("button",ue,[o(c(G),{size:18,class:"theme-icon icon"}),n(" "+s(t.$t("navbar.theme_dark")),1)])]),e("li",null,[e("button",pe,[o(c(M),{size:18,class:"theme-icon icon"}),n(" "+s(t.$t("navbar.theme_slate")),1)])]),e("li",null,[e("button",be,[o(c(I),{size:18,class:"theme-icon icon"}),n(" "+s(t.$t("navbar.theme_moonlight")),1)])]),e("li",null,[e("button",ve,[o(c(V),{size:18,class:"theme-icon icon"}),n(" "+s(t.$t("navbar.theme_midnight")),1)])]),e("li",null,[e("button",ye,[o(c(B),{size:18,class:"theme-icon icon"}),n(" "+s(t.$t("navbar.theme_ember")),1)])]),e("li",null,[e("button",ge,[o(c(W),{size:18,class:"theme-icon icon"}),n(" "+s(t.$t("navbar.theme_nord")),1)])]),i[1]||(i[1]=e("li",null,[e("hr",{class:"dropdown-divider"})],-1)),e("li",null,[e("button",ke,[o(c(Y),{size:18,class:"theme-icon icon"}),n(" "+s(t.$t("navbar.theme_light")),1)])]),e("li",null,[e("button",fe,[o(c(K),{size:18,class:"theme-icon icon"}),n(" "+s(t.$t("navbar.theme_indigo")),1)])]),e("li",null,[e("button",_e,[o(c(ee),{size:18,class:"theme-icon icon"}),n(" "+s(t.$t("navbar.theme_sunshine")),1)])]),e("li",null,[e("button",we,[o(c(ae),{size:18,class:"theme-icon icon"}),n(" "+s(t.$t("navbar.theme_ocean")),1)])]),e("li",null,[e("button",Me,[o(c(te),{size:18,class:"theme-icon icon"}),n(" "+s(t.$t("navbar.theme_forest")),1)])]),e("li",null,[e("button",$e,[o(c(D),{size:18,class:"theme-icon icon"}),n(" "+s(t.$t("navbar.theme_rose")),1)])]),e("li",null,[e("button",ze,[o(c(P),{size:18,class:"theme-icon icon"}),n(" "+s(t.$t("navbar.theme_lavender")),1)])]),e("li",null,[e("button",Se,[o(c(R),{size:18,class:"theme-icon icon"}),n(" "+s(t.$t("navbar.theme_monochrome")),1)])])])]))}},xe=""+new URL("../images/logo-sunshine-45.png",import.meta.url).href,Le={components:{ThemeToggle:Te,Notification:N,Home:O,Lock:F,Layers:M,Star:Q,Settings:X,Shield:J,Info:E,CircleUserRound:U,LogOut:Z},created(){console.log("Header mounted!")},mounted(){const a=globalThis.location.pathname.replace(/\/$/,"")||"/",t=document.querySelectorAll(".navbar-sunshine a[href]");for(const i of t){const d=i.getAttribute("href");!d||d==="#"||(new URL(d,globalThis.location.href).pathname.replace(/\/$/,"")||"/")!==a||i.classList.add("active")}},methods:{logout(){const a=Date.now().toString(),t=new URL("/logout",globalThis.location.href),i=new XMLHttpRequest,d=()=>{globalThis.location.replace(t.toString())};i.open("GET","/",!0,"sunshine-logout",a),i.setRequestHeader("Cache-Control","no-store"),i.onload=d,i.onerror=d,i.ontimeout=d,i.timeout=5e3,i.send()}}},qe={class:"navbar navbar-expand-lg navbar-sunshine"},Ce={class:"container-fluid"},Ae={class:"collapse navbar-collapse",id:"navbarSupportedContent"},je={class:"navbar-nav me-auto mb-2 mb-lg-0"},He={class:"nav-item"},Ee={class:"nav-link",href:"./"},Ne={class:"nav-item"},Ue={class:"nav-link",href:"./pin"},Ie={class:"nav-item"},Ve={class:"nav-link",href:"./apps"},Re={class:"nav-item"},Be={class:"nav-link",href:"./featured"},Pe={class:"nav-item"},De={class:"nav-link",href:"./config"},Oe={class:"nav-item"},Fe={class:"nav-link",href:"./troubleshooting"},Ze={class:"navbar-nav ms-auto mb-2 mb-lg-0"},Ge={class:"nav-item"},We={class:"nav-item dropdown"},Xe={class:"nav-link dropdown-toggle",type:"button",id:"navbarUserMenu","data-bs-toggle":"dropdown","aria-expanded":"false","aria-label":"User menu",title:"User menu"},Je={class:"dropdown-menu dropdown-menu-end","aria-labelledby":"navbarUserMenu"},Ke={class:"dropdown-item d-flex align-items-center",href:"./password"};function Qe(a,t,i,d,m,h){const u=r("Home"),v=r("Lock"),y=r("Layers"),p=r("Star"),z=r("Settings"),S=r("Info"),T=r("ThemeToggle"),x=r("CircleUserRound"),L=r("Shield"),q=r("LogOut"),C=r("Notification");return w(),_("div",null,[e("nav",qe,[e("div",Ce,[t[2]||(t[2]=e("a",{class:"navbar-brand",href:"./",title:"Sunshine"},[e("img",{src:xe,height:"45",alt:"Sunshine"})],-1)),t[3]||(t[3]=e("button",{class:"navbar-toggler",type:"button","data-bs-toggle":"collapse","data-bs-target":"#navbarSupportedContent","aria-controls":"navbarSupportedContent","aria-expanded":"false","aria-label":"Toggle navigation"},[e("span",{class:"navbar-toggler-icon"})],-1)),e("div",Ae,[e("ul",je,[e("li",He,[e("a",Ee,[o(u,{size:18,class:"icon"}),n(" "+s(a.$t("navbar.home")),1)])]),e("li",Ne,[e("a",Ue,[o(v,{size:18,class:"icon"}),n(" "+s(a.$t("navbar.pin")),1)])]),e("li",Ie,[e("a",Ve,[o(y,{size:18,class:"icon"}),n(" "+s(a.$t("navbar.applications")),1)])]),e("li",Re,[e("a",Be,[o(p,{size:18,class:"icon"}),n(" "+s(a.$t("navbar.featured")),1)])]),e("li",Pe,[e("a",De,[o(z,{size:18,class:"icon"}),n(" "+s(a.$t("navbar.configuration")),1)])]),e("li",Oe,[e("a",Fe,[o(S,{size:18,class:"icon"}),n(" "+s(a.$t("navbar.troubleshoot")),1)])])]),e("ul",Ze,[e("li",Ge,[o(T)]),e("li",We,[e("button",Xe,[o(x,{size:18,class:"icon"})]),e("ul",Je,[e("li",null,[e("a",Ke,[o(L,{size:18,class:"icon"}),n(" "+s(a.$t("navbar.password")),1)])]),t[1]||(t[1]=e("li",null,[e("hr",{class:"dropdown-divider"})],-1)),e("li",null,[e("button",{type:"button",class:"dropdown-item d-flex align-items-center",onClick:t[0]||(t[0]=(...A)=>h.logout&&h.logout(...A))},[o(q,{size:18,class:"icon"}),n(" "+s(a.$t("navbar.logout")),1)])])])])])])])]),o(C)])}const tt=H(Le,[["render",Qe]]);export{tt as N,J as S,X as a,Q as b};
