import{G as _,_ as p}from"./SimpleIcon-BGMhT-IK.js";import{D as c,o as b,d as h,e as s,t,h as o,j as r,F as m}from"./createLucideIcon-mjjtyxlm.js";import{_ as u,a as f}from"./Notification-E6BjStlk.js";import{F as g}from"./file-text-DLPhJfqV.js";const $={components:{SimpleIcon:p,AlertCircle:f,FileText:g,Globe:_}},y={class:"card"},z={class:"card-body"},v={class:"d-flex flex-wrap gap-2 mt-4"},C={class:"btn btn-success",href:"https://app.lizardbyte.dev",target:"_blank"},k={class:"btn btn-primary",href:"https://app.lizardbyte.dev/discord",target:"_blank"},S={class:"btn btn-secondary",href:"https://github.com/orgs/LizardByte/discussions",target:"_blank"},B={class:"card mt-4"},F={class:"card-body"},G={class:"d-flex flex-wrap gap-2 mt-4"},I={class:"btn btn-danger",href:"https://github.com/LizardByte/Sunshine/blob/master/LICENSE",target:"_blank"},N={class:"btn btn-danger",href:"https://github.com/LizardByte/Sunshine/blob/master/NOTICE",target:"_blank"};function T(e,a,A,D,E,L){const i=c("Globe"),n=c("SimpleIcon"),l=c("FileText"),d=c("AlertCircle");return b(),h(m,null,[s("div",y,[s("div",z,[s("h2",null,t(e.$t("resource_card.resources")),1),s("p",null,t(e.$t("resource_card.resources_desc")),1),s("div",v,[s("a",C,[o(i,{size:18,class:"icon"}),r(" "+t(e.$t("resource_card.lizardbyte_website")),1)]),s("a",k,[o(n,{icon:"Discord",size:18,class:"icon"}),a[0]||(a[0]=r(" Discord ",-1))]),s("a",S,[o(n,{icon:"GitHub",size:18,class:"icon"}),r(" "+t(e.$t("resource_card.github_discussions")),1)])])])]),s("div",B,[s("div",F,[s("h2",null,t(e.$t("resource_card.legal")),1),s("p",null,t(e.$t("resource_card.legal_desc")),1),s("div",G,[s("a",I,[o(l,{size:18,class:"icon"}),r(" "+t(e.$t("resource_card.license")),1)]),s("a",N,[o(d,{size:18,class:"icon"}),r(" "+t(e.$t("resource_card.third_party_notice")),1)])])])])],64)}const j=u($,[["render",T]]);export{j as R};
