import{c as b,a as B,i as V}from"./createLucideIcon-mjjtyxlm.js";import{b as J,N as z}from"./Navbar-e42_J4ze.js";import{G as $,_ as U}from"./SimpleIcon-BGMhT-IK.js";import{M as K}from"./monitor-DGvs6yC0.js";import{G as Z}from"./gamepad-2-DxOHyImA.js";import"./Notification-E6BjStlk.js";/**
 * @license lucide-vue-next v1.0.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const ee=b("box",[["path",{d:"M21 8a2 2 0 0 0-1-1.73l-7-4a2 2 0 0 0-2 0l-7 4A2 2 0 0 0 3 8v8a2 2 0 0 0 1 1.73l7 4a2 2 0 0 0 2 0l7-4A2 2 0 0 0 21 16Z",key:"hh9hay"}],["path",{d:"m3.3 7 8.7 5 8.7-5",key:"g66t2b"}],["path",{d:"M12 22V12",key:"d0xqtd"}]]);/**
 * @license lucide-vue-next v1.0.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const te=b("chevron-left",[["path",{d:"m15 18-6-6 6-6",key:"1wnfg3"}]]);/**
 * @license lucide-vue-next v1.0.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const ne=b("chevron-right",[["path",{d:"m9 18 6-6-6-6",key:"mthhwq"}]]);/**
 * @license lucide-vue-next v1.0.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const re=b("circle-arrow-down",[["circle",{cx:"12",cy:"12",r:"10",key:"1mglay"}],["path",{d:"M12 8v8",key:"napkw2"}],["path",{d:"m8 12 4 4 4-4",key:"k98ssh"}]]);/**
 * @license lucide-vue-next v1.0.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const ae=b("circle-dot",[["circle",{cx:"12",cy:"12",r:"10",key:"1mglay"}],["circle",{cx:"12",cy:"12",r:"1",key:"41hilf"}]]);/**
 * @license lucide-vue-next v1.0.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const se=b("external-link",[["path",{d:"M15 3h6v6",key:"1q9fwt"}],["path",{d:"M10 14 21 3",key:"gplh6r"}],["path",{d:"M18 13v6a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2V8a2 2 0 0 1 2-2h6",key:"a6xqqp"}]]);/**
 * @license lucide-vue-next v1.0.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const ie=b("gamepad",[["line",{x1:"6",x2:"10",y1:"12",y2:"12",key:"161bw2"}],["line",{x1:"8",x2:"8",y1:"10",y2:"14",key:"1i6ji0"}],["line",{x1:"15",x2:"15.01",y1:"13",y2:"13",key:"dqpgro"}],["line",{x1:"18",x2:"18.01",y1:"11",y2:"11",key:"meh2c"}],["rect",{width:"20",height:"12",x:"2",y:"6",rx:"2",key:"9lu3g6"}]]);/**
 * @license lucide-vue-next v1.0.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const oe=b("git-fork",[["circle",{cx:"12",cy:"18",r:"3",key:"1mpf1b"}],["circle",{cx:"6",cy:"6",r:"3",key:"1lh9wr"}],["circle",{cx:"18",cy:"6",r:"3",key:"1h7g24"}],["path",{d:"M18 9v2c0 .6-.4 1-1 1H7c-.6 0-1-.4-1-1V9",key:"1uq4wg"}],["path",{d:"M12 12v3",key:"158kv8"}]]);/**
 * @license lucide-vue-next v1.0.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const ce=b("smartphone",[["rect",{width:"14",height:"20",x:"5",y:"2",rx:"2",ry:"2",key:"1yt0o3"}],["path",{d:"M12 18h.01",key:"mhygvu"}]]);/**
 * @license lucide-vue-next v1.0.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const ue=b("tv",[["path",{d:"m17 2-5 5-5-5",key:"16satq"}],["rect",{width:"20",height:"15",x:"2",y:"7",rx:"2",key:"1e6viu"}]]),L=6048e5,de=864e5,W=43200,q=1440,N=Symbol.for("constructDateFrom");function M(t,e){return typeof t=="function"?t(e):t&&typeof t=="object"&&N in t?t[N](e):t instanceof Date?new t.constructor(e):new Date(e)}function g(t,e){return M(e||t,t)}let he={};function P(){return he}function O(t,e){var i,u,d,f;const n=P(),r=(e==null?void 0:e.weekStartsOn)??((u=(i=e==null?void 0:e.locale)==null?void 0:i.options)==null?void 0:u.weekStartsOn)??n.weekStartsOn??((f=(d=n.locale)==null?void 0:d.options)==null?void 0:f.weekStartsOn)??0,a=g(t,e==null?void 0:e.in),s=a.getDay(),o=(s<r?7:0)+s-r;return a.setDate(a.getDate()-o),a.setHours(0,0,0,0),a}function Y(t,e){return O(t,{...e,weekStartsOn:1})}function G(t,e){const n=g(t,e==null?void 0:e.in),r=n.getFullYear(),a=M(n,0);a.setFullYear(r+1,0,4),a.setHours(0,0,0,0);const s=Y(a),o=M(n,0);o.setFullYear(r,0,4),o.setHours(0,0,0,0);const i=Y(o);return n.getTime()>=s.getTime()?r+1:n.getTime()>=i.getTime()?r:r-1}function p(t){const e=g(t),n=new Date(Date.UTC(e.getFullYear(),e.getMonth(),e.getDate(),e.getHours(),e.getMinutes(),e.getSeconds(),e.getMilliseconds()));return n.setUTCFullYear(e.getFullYear()),+t-+n}function E(t,...e){const n=M.bind(null,t||e.find(r=>typeof r=="object"));return e.map(n)}function X(t,e){const n=g(t,e==null?void 0:e.in);return n.setHours(0,0,0,0),n}function fe(t,e,n){const[r,a]=E(n==null?void 0:n.in,t,e),s=X(r),o=X(a),i=+s-p(s),u=+o-p(o);return Math.round((i-u)/de)}function le(t,e){const n=G(t,e),r=M(t,0);return r.setFullYear(n,0,4),r.setHours(0,0,0,0),Y(r)}function T(t,e){const n=+g(t)-+g(e);return n<0?-1:n>0?1:n}function me(t){return M(t,Date.now())}function ge(t){return t instanceof Date||typeof t=="object"&&Object.prototype.toString.call(t)==="[object Date]"}function ye(t){return!(!ge(t)&&typeof t!="number"||isNaN(+g(t)))}function we(t,e,n){const[r,a]=E(n==null?void 0:n.in,t,e),s=r.getFullYear()-a.getFullYear(),o=r.getMonth()-a.getMonth();return s*12+o}function be(t){return e=>{const r=(t?Math[t]:Math.trunc)(e);return r===0?0:r}}function Me(t,e){return+g(t)-+g(e)}function xe(t,e){const n=g(t,e==null?void 0:e.in);return n.setHours(23,59,59,999),n}function Se(t,e){const n=g(t,e==null?void 0:e.in),r=n.getMonth();return n.setFullYear(n.getFullYear(),r+1,0),n.setHours(23,59,59,999),n}function ke(t,e){const n=g(t,e==null?void 0:e.in);return+xe(n,e)==+Se(n,e)}function De(t,e,n){const[r,a,s]=E(n==null?void 0:n.in,t,t,e),o=T(a,s),i=Math.abs(we(a,s));if(i<1)return 0;a.getMonth()===1&&a.getDate()>27&&a.setDate(30),a.setMonth(a.getMonth()-o*i);let u=T(a,s)===-o;ke(r)&&i===1&&T(r,s)===1&&(u=!1);const d=o*(i-+u);return d===0?0:d}function ve(t,e,n){const r=Me(t,e)/1e3;return be(n==null?void 0:n.roundingMethod)(r)}function Oe(t,e){const n=g(t,e==null?void 0:e.in);return n.setFullYear(n.getFullYear(),0,1),n.setHours(0,0,0,0),n}const Pe={lessThanXSeconds:{one:"less than a second",other:"less than {{count}} seconds"},xSeconds:{one:"1 second",other:"{{count}} seconds"},halfAMinute:"half a minute",lessThanXMinutes:{one:"less than a minute",other:"less than {{count}} minutes"},xMinutes:{one:"1 minute",other:"{{count}} minutes"},aboutXHours:{one:"about 1 hour",other:"about {{count}} hours"},xHours:{one:"1 hour",other:"{{count}} hours"},xDays:{one:"1 day",other:"{{count}} days"},aboutXWeeks:{one:"about 1 week",other:"about {{count}} weeks"},xWeeks:{one:"1 week",other:"{{count}} weeks"},aboutXMonths:{one:"about 1 month",other:"about {{count}} months"},xMonths:{one:"1 month",other:"{{count}} months"},aboutXYears:{one:"about 1 year",other:"about {{count}} years"},xYears:{one:"1 year",other:"{{count}} years"},overXYears:{one:"over 1 year",other:"over {{count}} years"},almostXYears:{one:"almost 1 year",other:"almost {{count}} years"}},We=(t,e,n)=>{let r;const a=Pe[t];return typeof a=="string"?r=a:e===1?r=a.one:r=a.other.replace("{{count}}",e.toString()),n!=null&&n.addSuffix?n.comparison&&n.comparison>0?"in "+r:r+" ago":r};function C(t){return(e={})=>{const n=e.width?String(e.width):t.defaultWidth;return t.formats[n]||t.formats[t.defaultWidth]}}const Te={full:"EEEE, MMMM do, y",long:"MMMM do, y",medium:"MMM d, y",short:"MM/dd/yyyy"},Ye={full:"h:mm:ss a zzzz",long:"h:mm:ss a z",medium:"h:mm:ss a",short:"h:mm a"},pe={full:"{{date}} 'at' {{time}}",long:"{{date}} 'at' {{time}}",medium:"{{date}}, {{time}}",short:"{{date}}, {{time}}"},Ee={date:C({formats:Te,defaultWidth:"full"}),time:C({formats:Ye,defaultWidth:"full"}),dateTime:C({formats:pe,defaultWidth:"full"})},Fe={lastWeek:"'last' eeee 'at' p",yesterday:"'yesterday at' p",today:"'today at' p",tomorrow:"'tomorrow at' p",nextWeek:"eeee 'at' p",other:"P"},Ce=(t,e,n,r)=>Fe[t];function D(t){return(e,n)=>{const r=n!=null&&n.context?String(n.context):"standalone";let a;if(r==="formatting"&&t.formattingValues){const o=t.defaultFormattingWidth||t.defaultWidth,i=n!=null&&n.width?String(n.width):o;a=t.formattingValues[i]||t.formattingValues[o]}else{const o=t.defaultWidth,i=n!=null&&n.width?String(n.width):t.defaultWidth;a=t.values[i]||t.values[o]}const s=t.argumentCallback?t.argumentCallback(e):e;return a[s]}}const qe={narrow:["B","A"],abbreviated:["BC","AD"],wide:["Before Christ","Anno Domini"]},Ne={narrow:["1","2","3","4"],abbreviated:["Q1","Q2","Q3","Q4"],wide:["1st quarter","2nd quarter","3rd quarter","4th quarter"]},Xe={narrow:["J","F","M","A","M","J","J","A","S","O","N","D"],abbreviated:["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"],wide:["January","February","March","April","May","June","July","August","September","October","November","December"]},Ae={narrow:["S","M","T","W","T","F","S"],short:["Su","Mo","Tu","We","Th","Fr","Sa"],abbreviated:["Sun","Mon","Tue","Wed","Thu","Fri","Sat"],wide:["Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday"]},_e={narrow:{am:"a",pm:"p",midnight:"mi",noon:"n",morning:"morning",afternoon:"afternoon",evening:"evening",night:"night"},abbreviated:{am:"AM",pm:"PM",midnight:"midnight",noon:"noon",morning:"morning",afternoon:"afternoon",evening:"evening",night:"night"},wide:{am:"a.m.",pm:"p.m.",midnight:"midnight",noon:"noon",morning:"morning",afternoon:"afternoon",evening:"evening",night:"night"}},Ie={narrow:{am:"a",pm:"p",midnight:"mi",noon:"n",morning:"in the morning",afternoon:"in the afternoon",evening:"in the evening",night:"at night"},abbreviated:{am:"AM",pm:"PM",midnight:"midnight",noon:"noon",morning:"in the morning",afternoon:"in the afternoon",evening:"in the evening",night:"at night"},wide:{am:"a.m.",pm:"p.m.",midnight:"midnight",noon:"noon",morning:"in the morning",afternoon:"in the afternoon",evening:"in the evening",night:"at night"}},He=(t,e)=>{const n=Number(t),r=n%100;if(r>20||r<10)switch(r%10){case 1:return n+"st";case 2:return n+"nd";case 3:return n+"rd"}return n+"th"},Le={ordinalNumber:He,era:D({values:qe,defaultWidth:"wide"}),quarter:D({values:Ne,defaultWidth:"wide",argumentCallback:t=>t-1}),month:D({values:Xe,defaultWidth:"wide"}),day:D({values:Ae,defaultWidth:"wide"}),dayPeriod:D({values:_e,defaultWidth:"wide",formattingValues:Ie,defaultFormattingWidth:"wide"})};function v(t){return(e,n={})=>{const r=n.width,a=r&&t.matchPatterns[r]||t.matchPatterns[t.defaultMatchWidth],s=e.match(a);if(!s)return null;const o=s[0],i=r&&t.parsePatterns[r]||t.parsePatterns[t.defaultParseWidth],u=Array.isArray(i)?Qe(i,w=>w.test(o)):Ge(i,w=>w.test(o));let d;d=t.valueCallback?t.valueCallback(u):u,d=n.valueCallback?n.valueCallback(d):d;const f=e.slice(o.length);return{value:d,rest:f}}}function Ge(t,e){for(const n in t)if(Object.prototype.hasOwnProperty.call(t,n)&&e(t[n]))return n}function Qe(t,e){for(let n=0;n<t.length;n++)if(e(t[n]))return n}function je(t){return(e,n={})=>{const r=e.match(t.matchPattern);if(!r)return null;const a=r[0],s=e.match(t.parsePattern);if(!s)return null;let o=t.valueCallback?t.valueCallback(s[0]):s[0];o=n.valueCallback?n.valueCallback(o):o;const i=e.slice(a.length);return{value:o,rest:i}}}const Re=/^(\d+)(th|st|nd|rd)?/i,Be=/\d+/i,Ve={narrow:/^(b|a)/i,abbreviated:/^(b\.?\s?c\.?|b\.?\s?c\.?\s?e\.?|a\.?\s?d\.?|c\.?\s?e\.?)/i,wide:/^(before christ|before common era|anno domini|common era)/i},Je={any:[/^b/i,/^(a|c)/i]},ze={narrow:/^[1234]/i,abbreviated:/^q[1234]/i,wide:/^[1234](th|st|nd|rd)? quarter/i},$e={any:[/1/i,/2/i,/3/i,/4/i]},Ue={narrow:/^[jfmasond]/i,abbreviated:/^(jan|feb|mar|apr|may|jun|jul|aug|sep|oct|nov|dec)/i,wide:/^(january|february|march|april|may|june|july|august|september|october|november|december)/i},Ke={narrow:[/^j/i,/^f/i,/^m/i,/^a/i,/^m/i,/^j/i,/^j/i,/^a/i,/^s/i,/^o/i,/^n/i,/^d/i],any:[/^ja/i,/^f/i,/^mar/i,/^ap/i,/^may/i,/^jun/i,/^jul/i,/^au/i,/^s/i,/^o/i,/^n/i,/^d/i]},Ze={narrow:/^[smtwf]/i,short:/^(su|mo|tu|we|th|fr|sa)/i,abbreviated:/^(sun|mon|tue|wed|thu|fri|sat)/i,wide:/^(sunday|monday|tuesday|wednesday|thursday|friday|saturday)/i},et={narrow:[/^s/i,/^m/i,/^t/i,/^w/i,/^t/i,/^f/i,/^s/i],any:[/^su/i,/^m/i,/^tu/i,/^w/i,/^th/i,/^f/i,/^sa/i]},tt={narrow:/^(a|p|mi|n|(in the|at) (morning|afternoon|evening|night))/i,any:/^([ap]\.?\s?m\.?|midnight|noon|(in the|at) (morning|afternoon|evening|night))/i},nt={any:{am:/^a/i,pm:/^p/i,midnight:/^mi/i,noon:/^no/i,morning:/morning/i,afternoon:/afternoon/i,evening:/evening/i,night:/night/i}},rt={ordinalNumber:je({matchPattern:Re,parsePattern:Be,valueCallback:t=>parseInt(t,10)}),era:v({matchPatterns:Ve,defaultMatchWidth:"wide",parsePatterns:Je,defaultParseWidth:"any"}),quarter:v({matchPatterns:ze,defaultMatchWidth:"wide",parsePatterns:$e,defaultParseWidth:"any",valueCallback:t=>t+1}),month:v({matchPatterns:Ue,defaultMatchWidth:"wide",parsePatterns:Ke,defaultParseWidth:"any"}),day:v({matchPatterns:Ze,defaultMatchWidth:"wide",parsePatterns:et,defaultParseWidth:"any"}),dayPeriod:v({matchPatterns:tt,defaultMatchWidth:"any",parsePatterns:nt,defaultParseWidth:"any"})},Q={code:"en-US",formatDistance:We,formatLong:Ee,formatRelative:Ce,localize:Le,match:rt,options:{weekStartsOn:0,firstWeekContainsDate:1}};function at(t,e){const n=g(t,e==null?void 0:e.in);return fe(n,Oe(n))+1}function st(t,e){const n=g(t,e==null?void 0:e.in),r=+Y(n)-+le(n);return Math.round(r/L)+1}function j(t,e){var f,w,l,y;const n=g(t,e==null?void 0:e.in),r=n.getFullYear(),a=P(),s=(e==null?void 0:e.firstWeekContainsDate)??((w=(f=e==null?void 0:e.locale)==null?void 0:f.options)==null?void 0:w.firstWeekContainsDate)??a.firstWeekContainsDate??((y=(l=a.locale)==null?void 0:l.options)==null?void 0:y.firstWeekContainsDate)??1,o=M((e==null?void 0:e.in)||t,0);o.setFullYear(r+1,0,s),o.setHours(0,0,0,0);const i=O(o,e),u=M((e==null?void 0:e.in)||t,0);u.setFullYear(r,0,s),u.setHours(0,0,0,0);const d=O(u,e);return+n>=+i?r+1:+n>=+d?r:r-1}function it(t,e){var i,u,d,f;const n=P(),r=(e==null?void 0:e.firstWeekContainsDate)??((u=(i=e==null?void 0:e.locale)==null?void 0:i.options)==null?void 0:u.firstWeekContainsDate)??n.firstWeekContainsDate??((f=(d=n.locale)==null?void 0:d.options)==null?void 0:f.firstWeekContainsDate)??1,a=j(t,e),s=M((e==null?void 0:e.in)||t,0);return s.setFullYear(a,0,r),s.setHours(0,0,0,0),O(s,e)}function ot(t,e){const n=g(t,e==null?void 0:e.in),r=+O(n,e)-+it(n,e);return Math.round(r/L)+1}function c(t,e){const n=t<0?"-":"",r=Math.abs(t).toString().padStart(e,"0");return n+r}const x={y(t,e){const n=t.getFullYear(),r=n>0?n:1-n;return c(e==="yy"?r%100:r,e.length)},M(t,e){const n=t.getMonth();return e==="M"?String(n+1):c(n+1,2)},d(t,e){return c(t.getDate(),e.length)},a(t,e){const n=t.getHours()/12>=1?"pm":"am";switch(e){case"a":case"aa":return n.toUpperCase();case"aaa":return n;case"aaaaa":return n[0];case"aaaa":default:return n==="am"?"a.m.":"p.m."}},h(t,e){return c(t.getHours()%12||12,e.length)},H(t,e){return c(t.getHours(),e.length)},m(t,e){return c(t.getMinutes(),e.length)},s(t,e){return c(t.getSeconds(),e.length)},S(t,e){const n=e.length,r=t.getMilliseconds(),a=Math.trunc(r*Math.pow(10,n-3));return c(a,e.length)}},k={midnight:"midnight",noon:"noon",morning:"morning",afternoon:"afternoon",evening:"evening",night:"night"},A={G:function(t,e,n){const r=t.getFullYear()>0?1:0;switch(e){case"G":case"GG":case"GGG":return n.era(r,{width:"abbreviated"});case"GGGGG":return n.era(r,{width:"narrow"});case"GGGG":default:return n.era(r,{width:"wide"})}},y:function(t,e,n){if(e==="yo"){const r=t.getFullYear(),a=r>0?r:1-r;return n.ordinalNumber(a,{unit:"year"})}return x.y(t,e)},Y:function(t,e,n,r){const a=j(t,r),s=a>0?a:1-a;if(e==="YY"){const o=s%100;return c(o,2)}return e==="Yo"?n.ordinalNumber(s,{unit:"year"}):c(s,e.length)},R:function(t,e){const n=G(t);return c(n,e.length)},u:function(t,e){const n=t.getFullYear();return c(n,e.length)},Q:function(t,e,n){const r=Math.ceil((t.getMonth()+1)/3);switch(e){case"Q":return String(r);case"QQ":return c(r,2);case"Qo":return n.ordinalNumber(r,{unit:"quarter"});case"QQQ":return n.quarter(r,{width:"abbreviated",context:"formatting"});case"QQQQQ":return n.quarter(r,{width:"narrow",context:"formatting"});case"QQQQ":default:return n.quarter(r,{width:"wide",context:"formatting"})}},q:function(t,e,n){const r=Math.ceil((t.getMonth()+1)/3);switch(e){case"q":return String(r);case"qq":return c(r,2);case"qo":return n.ordinalNumber(r,{unit:"quarter"});case"qqq":return n.quarter(r,{width:"abbreviated",context:"standalone"});case"qqqqq":return n.quarter(r,{width:"narrow",context:"standalone"});case"qqqq":default:return n.quarter(r,{width:"wide",context:"standalone"})}},M:function(t,e,n){const r=t.getMonth();switch(e){case"M":case"MM":return x.M(t,e);case"Mo":return n.ordinalNumber(r+1,{unit:"month"});case"MMM":return n.month(r,{width:"abbreviated",context:"formatting"});case"MMMMM":return n.month(r,{width:"narrow",context:"formatting"});case"MMMM":default:return n.month(r,{width:"wide",context:"formatting"})}},L:function(t,e,n){const r=t.getMonth();switch(e){case"L":return String(r+1);case"LL":return c(r+1,2);case"Lo":return n.ordinalNumber(r+1,{unit:"month"});case"LLL":return n.month(r,{width:"abbreviated",context:"standalone"});case"LLLLL":return n.month(r,{width:"narrow",context:"standalone"});case"LLLL":default:return n.month(r,{width:"wide",context:"standalone"})}},w:function(t,e,n,r){const a=ot(t,r);return e==="wo"?n.ordinalNumber(a,{unit:"week"}):c(a,e.length)},I:function(t,e,n){const r=st(t);return e==="Io"?n.ordinalNumber(r,{unit:"week"}):c(r,e.length)},d:function(t,e,n){return e==="do"?n.ordinalNumber(t.getDate(),{unit:"date"}):x.d(t,e)},D:function(t,e,n){const r=at(t);return e==="Do"?n.ordinalNumber(r,{unit:"dayOfYear"}):c(r,e.length)},E:function(t,e,n){const r=t.getDay();switch(e){case"E":case"EE":case"EEE":return n.day(r,{width:"abbreviated",context:"formatting"});case"EEEEE":return n.day(r,{width:"narrow",context:"formatting"});case"EEEEEE":return n.day(r,{width:"short",context:"formatting"});case"EEEE":default:return n.day(r,{width:"wide",context:"formatting"})}},e:function(t,e,n,r){const a=t.getDay(),s=(a-r.weekStartsOn+8)%7||7;switch(e){case"e":return String(s);case"ee":return c(s,2);case"eo":return n.ordinalNumber(s,{unit:"day"});case"eee":return n.day(a,{width:"abbreviated",context:"formatting"});case"eeeee":return n.day(a,{width:"narrow",context:"formatting"});case"eeeeee":return n.day(a,{width:"short",context:"formatting"});case"eeee":default:return n.day(a,{width:"wide",context:"formatting"})}},c:function(t,e,n,r){const a=t.getDay(),s=(a-r.weekStartsOn+8)%7||7;switch(e){case"c":return String(s);case"cc":return c(s,e.length);case"co":return n.ordinalNumber(s,{unit:"day"});case"ccc":return n.day(a,{width:"abbreviated",context:"standalone"});case"ccccc":return n.day(a,{width:"narrow",context:"standalone"});case"cccccc":return n.day(a,{width:"short",context:"standalone"});case"cccc":default:return n.day(a,{width:"wide",context:"standalone"})}},i:function(t,e,n){const r=t.getDay(),a=r===0?7:r;switch(e){case"i":return String(a);case"ii":return c(a,e.length);case"io":return n.ordinalNumber(a,{unit:"day"});case"iii":return n.day(r,{width:"abbreviated",context:"formatting"});case"iiiii":return n.day(r,{width:"narrow",context:"formatting"});case"iiiiii":return n.day(r,{width:"short",context:"formatting"});case"iiii":default:return n.day(r,{width:"wide",context:"formatting"})}},a:function(t,e,n){const a=t.getHours()/12>=1?"pm":"am";switch(e){case"a":case"aa":return n.dayPeriod(a,{width:"abbreviated",context:"formatting"});case"aaa":return n.dayPeriod(a,{width:"abbreviated",context:"formatting"}).toLowerCase();case"aaaaa":return n.dayPeriod(a,{width:"narrow",context:"formatting"});case"aaaa":default:return n.dayPeriod(a,{width:"wide",context:"formatting"})}},b:function(t,e,n){const r=t.getHours();let a;switch(r===12?a=k.noon:r===0?a=k.midnight:a=r/12>=1?"pm":"am",e){case"b":case"bb":return n.dayPeriod(a,{width:"abbreviated",context:"formatting"});case"bbb":return n.dayPeriod(a,{width:"abbreviated",context:"formatting"}).toLowerCase();case"bbbbb":return n.dayPeriod(a,{width:"narrow",context:"formatting"});case"bbbb":default:return n.dayPeriod(a,{width:"wide",context:"formatting"})}},B:function(t,e,n){const r=t.getHours();let a;switch(r>=17?a=k.evening:r>=12?a=k.afternoon:r>=4?a=k.morning:a=k.night,e){case"B":case"BB":case"BBB":return n.dayPeriod(a,{width:"abbreviated",context:"formatting"});case"BBBBB":return n.dayPeriod(a,{width:"narrow",context:"formatting"});case"BBBB":default:return n.dayPeriod(a,{width:"wide",context:"formatting"})}},h:function(t,e,n){if(e==="ho"){let r=t.getHours()%12;return r===0&&(r=12),n.ordinalNumber(r,{unit:"hour"})}return x.h(t,e)},H:function(t,e,n){return e==="Ho"?n.ordinalNumber(t.getHours(),{unit:"hour"}):x.H(t,e)},K:function(t,e,n){const r=t.getHours()%12;return e==="Ko"?n.ordinalNumber(r,{unit:"hour"}):c(r,e.length)},k:function(t,e,n){let r=t.getHours();return r===0&&(r=24),e==="ko"?n.ordinalNumber(r,{unit:"hour"}):c(r,e.length)},m:function(t,e,n){return e==="mo"?n.ordinalNumber(t.getMinutes(),{unit:"minute"}):x.m(t,e)},s:function(t,e,n){return e==="so"?n.ordinalNumber(t.getSeconds(),{unit:"second"}):x.s(t,e)},S:function(t,e){return x.S(t,e)},X:function(t,e,n){const r=t.getTimezoneOffset();if(r===0)return"Z";switch(e){case"X":return I(r);case"XXXX":case"XX":return S(r);case"XXXXX":case"XXX":default:return S(r,":")}},x:function(t,e,n){const r=t.getTimezoneOffset();switch(e){case"x":return I(r);case"xxxx":case"xx":return S(r);case"xxxxx":case"xxx":default:return S(r,":")}},O:function(t,e,n){const r=t.getTimezoneOffset();switch(e){case"O":case"OO":case"OOO":return"GMT"+_(r,":");case"OOOO":default:return"GMT"+S(r,":")}},z:function(t,e,n){const r=t.getTimezoneOffset();switch(e){case"z":case"zz":case"zzz":return"GMT"+_(r,":");case"zzzz":default:return"GMT"+S(r,":")}},t:function(t,e,n){const r=Math.trunc(+t/1e3);return c(r,e.length)},T:function(t,e,n){return c(+t,e.length)}};function _(t,e=""){const n=t>0?"-":"+",r=Math.abs(t),a=Math.trunc(r/60),s=r%60;return s===0?n+String(a):n+String(a)+e+c(s,2)}function I(t,e){return t%60===0?(t>0?"-":"+")+c(Math.abs(t)/60,2):S(t,e)}function S(t,e=""){const n=t>0?"-":"+",r=Math.abs(t),a=c(Math.trunc(r/60),2),s=c(r%60,2);return n+a+e+s}const H=(t,e)=>{switch(t){case"P":return e.date({width:"short"});case"PP":return e.date({width:"medium"});case"PPP":return e.date({width:"long"});case"PPPP":default:return e.date({width:"full"})}},R=(t,e)=>{switch(t){case"p":return e.time({width:"short"});case"pp":return e.time({width:"medium"});case"ppp":return e.time({width:"long"});case"pppp":default:return e.time({width:"full"})}},ct=(t,e)=>{const n=t.match(/(P+)(p+)?/)||[],r=n[1],a=n[2];if(!a)return H(t,e);let s;switch(r){case"P":s=e.dateTime({width:"short"});break;case"PP":s=e.dateTime({width:"medium"});break;case"PPP":s=e.dateTime({width:"long"});break;case"PPPP":default:s=e.dateTime({width:"full"});break}return s.replace("{{date}}",H(r,e)).replace("{{time}}",R(a,e))},ut={p:R,P:ct},dt=/^D+$/,ht=/^Y+$/,ft=["D","DD","YY","YYYY"];function lt(t){return dt.test(t)}function mt(t){return ht.test(t)}function gt(t,e,n){const r=yt(t,e,n);if(console.warn(r),ft.includes(t))throw new RangeError(r)}function yt(t,e,n){const r=t[0]==="Y"?"years":"days of the month";return`Use \`${t.toLowerCase()}\` instead of \`${t}\` (in \`${e}\`) for formatting ${r} to the input \`${n}\`; see: https://github.com/date-fns/date-fns/blob/master/docs/unicodeTokens.md`}const wt=/[yYQqMLwIdDecihHKkms]o|(\w)\1*|''|'(''|[^'])+('|$)|./g,bt=/P+p+|P+|p+|''|'(''|[^'])+('|$)|./g,Mt=/^'([^]*?)'?$/,xt=/''/g,St=/[a-zA-Z]/;function kt(t,e,n){var f,w,l,y;const r=P(),a=r.locale??Q,s=r.firstWeekContainsDate??((w=(f=r.locale)==null?void 0:f.options)==null?void 0:w.firstWeekContainsDate)??1,o=r.weekStartsOn??((y=(l=r.locale)==null?void 0:l.options)==null?void 0:y.weekStartsOn)??0,i=g(t,n==null?void 0:n.in);if(!ye(i))throw new RangeError("Invalid time value");let u=e.match(bt).map(h=>{const m=h[0];if(m==="p"||m==="P"){const F=ut[m];return F(h,a.formatLong)}return h}).join("").match(wt).map(h=>{if(h==="''")return{isToken:!1,value:"'"};const m=h[0];if(m==="'")return{isToken:!1,value:Dt(h)};if(A[m])return{isToken:!0,value:h};if(m.match(St))throw new RangeError("Format string contains an unescaped latin alphabet character `"+m+"`");return{isToken:!1,value:h}});a.localize.preprocessor&&(u=a.localize.preprocessor(i,u));const d={firstWeekContainsDate:s,weekStartsOn:o,locale:a};return u.map(h=>{if(!h.isToken)return h.value;const m=h.value;(mt(m)||lt(m))&&gt(m,e,String(t));const F=A[m[0]];return F(i,m,a.localize,d)}).join("")}function Dt(t){const e=t.match(Mt);return e?e[1].replace(xt,"'"):t}function vt(t,e,n){const r=P(),a=(n==null?void 0:n.locale)??r.locale??Q,s=2520,o=T(t,e);if(isNaN(o))throw new RangeError("Invalid time value");const i=Object.assign({},n,{addSuffix:n==null?void 0:n.addSuffix,comparison:o}),[u,d]=E(n==null?void 0:n.in,...o>0?[e,t]:[t,e]),f=ve(d,u),w=(p(d)-p(u))/1e3,l=Math.round((f-w)/60);let y;if(l<2)return n!=null&&n.includeSeconds?f<5?a.formatDistance("lessThanXSeconds",5,i):f<10?a.formatDistance("lessThanXSeconds",10,i):f<20?a.formatDistance("lessThanXSeconds",20,i):f<40?a.formatDistance("halfAMinute",0,i):f<60?a.formatDistance("lessThanXMinutes",1,i):a.formatDistance("xMinutes",1,i):l===0?a.formatDistance("lessThanXMinutes",1,i):a.formatDistance("xMinutes",l,i);if(l<45)return a.formatDistance("xMinutes",l,i);if(l<90)return a.formatDistance("aboutXHours",1,i);if(l<q){const h=Math.round(l/60);return a.formatDistance("aboutXHours",h,i)}else{if(l<s)return a.formatDistance("xDays",1,i);if(l<W){const h=Math.round(l/q);return a.formatDistance("xDays",h,i)}else if(l<W*2)return y=Math.round(l/W),a.formatDistance("aboutXMonths",y,i)}if(y=De(d,u),y<12){const h=Math.round(l/W);return a.formatDistance("xMonths",h,i)}else{const h=y%12,m=Math.trunc(y/12);return h<3?a.formatDistance("aboutXYears",m,i):h<9?a.formatDistance("overXYears",m,i):a.formatDistance("almostXYears",m+1,i)}}function Ot(t,e){return vt(t,me(t),e)}const Pt=B({components:{Navbar:z,SimpleIcon:U,ArrowDownCircle:re,Box:ee,ChevronLeft:te,ChevronRight:ne,CircleDot:ae,ExternalLink:se,Gamepad:ie,Gamepad2:Z,GitFork:oe,Globe:$,Monitor:K,Smartphone:ce,Star:J,Tv:ue},data(){return{apps:[],categories:[],selectedCategory:null,loading:!0,error:null,selectedScreenshot:null,selectedScreenshotIndex:-1,currentAppScreenshots:[],touchStartX:0,touchEndX:0}},computed:{filteredApps(){return(this.selectedCategory?this.apps.filter(e=>e.category===this.selectedCategory):this.apps).slice().sort((e,n)=>{var s,o;if(e.official&&!n.official)return-1;if(!e.official&&n.official)return 1;const r=((s=e.github)==null?void 0:s.stars)||0;return(((o=n.github)==null?void 0:o.stars)||0)-r})}},created(){this.loadFeaturedApps()},mounted(){window.addEventListener("keydown",this.handleKeydown)},beforeUnmount(){window.removeEventListener("keydown",this.handleKeydown)},methods:{async loadFeaturedApps(){try{this.loading=!0,this.error=null;const e=await fetch("https://app.lizardbyte.dev/app-directory/sunshine.json");if(!e.ok)throw new Error("Failed to load featured apps");const n=await e.json();this.apps=n.apps||[],this.categories=n.categories||[]}catch(t){console.error("Error loading featured apps:",t),this.error=t.message}finally{this.loading=!1}},platformName(t){return{android:"Android",console:"Console",handheld:"Handheld",ios:"iOS",linux:"Linux",macos:"macOS",tv:"TV",web:"Web",windows:"Windows"}[t]||t},handleIconError(t){t.target.style.display="none"},openScreenshot(t,e){this.currentAppScreenshots=e||[],this.selectedScreenshotIndex=this.currentAppScreenshots.indexOf(t),this.selectedScreenshot=t},closeScreenshot(){this.selectedScreenshot=null,this.selectedScreenshotIndex=-1,this.currentAppScreenshots=[]},nextScreenshot(){this.currentAppScreenshots.length!==0&&(this.selectedScreenshotIndex=(this.selectedScreenshotIndex+1)%this.currentAppScreenshots.length,this.selectedScreenshot=this.currentAppScreenshots[this.selectedScreenshotIndex])},prevScreenshot(){this.currentAppScreenshots.length!==0&&(this.selectedScreenshotIndex=(this.selectedScreenshotIndex-1+this.currentAppScreenshots.length)%this.currentAppScreenshots.length,this.selectedScreenshot=this.currentAppScreenshots[this.selectedScreenshotIndex])},handleKeydown(t){this.selectedScreenshot&&(t.key==="ArrowRight"?(t.preventDefault(),this.nextScreenshot()):t.key==="ArrowLeft"?(t.preventDefault(),this.prevScreenshot()):t.key==="Escape"&&(t.preventDefault(),this.closeScreenshot()))},handleTouchStart(t){this.touchStartX=t.changedTouches[0].screenX},handleTouchEnd(t){this.touchEndX=t.changedTouches[0].screenX,this.handleSwipe()},handleSwipe(){const e=this.touchStartX-this.touchEndX;Math.abs(e)>50&&(e>0?this.nextScreenshot():this.prevScreenshot())},handleScreenshotError(t){t.target.style.display="none"},formatNumber(t){if(t==null)return"0";const e=Math.abs(t);return e>=1e9?(t/1e9).toFixed(1)+"B":e>=1e6?(t/1e6).toFixed(1)+"M":e>=1e3?(t/1e3).toFixed(1)+"k":t.toString()},formatDate(t){if(!t)return{relative:"",absolute:""};const e=new Date(t),n=kt(e,"MMM d, yyyy, h:mm a zzz");return{relative:Ot(e,{addSuffix:!0}),absolute:n}}}});V(Pt);
